@@ -76,7 +76,9 @@ sub build_terse {
 		$t->{plugin} = sub {
 			my ($t, $plugin) = @_;
 			$t->raiseError("invalid plugin: ${plugin}", 400) unless $self->plugins->{$plugin};
-			return $self->plugins->{$plugin};
+			return $t->plugins->$plugin ||= ($self->plugins->{$plugin}->can('connect') 
+				? $self->plugins->{$plugin}->connect() 
+				: $self->plugins->{$plugin});
 		};
 	}
 	return $t;
@@ -164,7 +166,7 @@ sub response_handle {
 	my ($content_type, $body) = $self->views->{$self->response_view} 
 		? $t->view($self->response_view)->render($t, $response_body) 
 		: ($ct, $response_body->serialize());
-	my $res = $t->_build_response($sid, $content_type, $response_body->status_code ||= $status ||= 200);
+	$res = $t->_build_response($sid, $content_type, $response_body->status_code ||= $status ||= 200);
 	$res->body($body);
 	return $res->finalize;
 }
@@ -238,7 +240,7 @@ Terse::Controller - controllers made simple.
 
 =head1 VERSION
 
-Version 0.108
+Version 0.109
 
 =cut
 
