@@ -23,7 +23,7 @@ Terse::Plugin - plugins made simple.
 
 =head1 VERSION
 
-Version 0.108
+Version 0.109
 
 =cut
 
@@ -53,7 +53,7 @@ Version 0.108
 
 	sub auth {
 		shift;
-		unless ($_[0]->plugin('validateparam')->az($_[0]->param->name)) {
+		unless ($_[0]->plugin('validateparam')->az($_[0]->params->name)) {
 			$_[0]->raiseError('param name contains more than just A-Z');
 			return 0;
 		}
@@ -73,7 +73,7 @@ Version 0.108
 	}
 
 	sub overview :get {
-		unless ($_[1]->plugin('validate')->az($_[1]->param->name)) {
+		unless ($_[1]->plugin('validate')->az($_[1]->params->name)) {
 			$_[1]->raiseError('param name contains more than just A-Z', 400);
 			return 0;
 		}
